#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shell-escape
version:              0.2.0
visibility:           public
id:                   shell-escape-0.2.0-2TK3R08vxkQ3Il1iZ95teW
key:                  shell-escape-0.2.0-2TK3R08vxkQ3Il1iZ95teW
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/shell-escape
synopsis:             Shell escaping library.
description:
    Shell escaping library, offering both Bourne shell and Bash style escaping
    of ByteStrings.

category:             Text
abi:                  a0c8b9b9731b6cdcc36fe52bbf8521e6
exposed:              True
exposed-modules:      Data.ByteString.ShellEscape Text.ShellEscape
hidden-modules:
    Data.ByteString.ShellEscape.Escape
    Data.ByteString.ShellEscape.EscapeVector
    Data.ByteString.ShellEscape.Sh Data.ByteString.ShellEscape.Bash
    Data.ByteString.ShellEscape.Put

import-dirs:          /usr/lib/ghc-9.6.6/site-local/shell-escape-0.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/shell-escape-0.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/shell-escape-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shell-escape
hs-libraries:         HSshell-escape-0.2.0-2TK3R08vxkQ3Il1iZ95teW
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    vector-0.13.2.0-AWRowWUrdYO1choGzrrEgg

haddock-interfaces:
    /usr/share/doc/haskell-shell-escape/html/shell-escape.haddock

haddock-html:         /usr/share/doc/haskell-shell-escape/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

